@@ -5,37 +5,37 @@ if [ -x /usr/bin/fc-cache ]; then
 fi
 # else we'll catch it later with setup.fontconfig :-)
 # make links:
-( cd usr/lib ; rm -rf libfontconfig.so )
-( cd usr/lib ; ln -sf libfontconfig.so.1.2.0 libfontconfig.so )
-( cd usr/lib ; rm -rf libfontconfig.so.1 )
-( cd usr/lib ; ln -sf libfontconfig.so.1.2.0 libfontconfig.so.1 )
-( cd etc/fonts/conf.d ; rm -rf 90-synthetic.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/90-synthetic.conf 90-synthetic.conf )
-( cd etc/fonts/conf.d ; rm -rf 20-lohit-gujarati.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-lohit-gujarati.conf 20-lohit-gujarati.conf )
-( cd etc/fonts/conf.d ; rm -rf 51-local.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/51-local.conf 51-local.conf )
-( cd etc/fonts/conf.d ; rm -rf 65-nonlatin.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-nonlatin.conf 65-nonlatin.conf )
-( cd etc/fonts/conf.d ; rm -rf 20-fix-globaladvance.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-fix-globaladvance.conf 20-fix-globaladvance.conf )
-( cd etc/fonts/conf.d ; rm -rf 49-sansserif.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/49-sansserif.conf 49-sansserif.conf )
-( cd etc/fonts/conf.d ; rm -rf 60-latin.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/60-latin.conf 60-latin.conf )
-( cd etc/fonts/conf.d ; rm -rf 80-delicious.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/80-delicious.conf 80-delicious.conf )
-( cd etc/fonts/conf.d ; rm -rf 20-unhint-small-vera.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-unhint-small-vera.conf 20-unhint-small-vera.conf )
-( cd etc/fonts/conf.d ; rm -rf 69-unifont.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/69-unifont.conf 69-unifont.conf )
-( cd etc/fonts/conf.d ; rm -rf 30-urw-aliases.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-urw-aliases.conf 30-urw-aliases.conf )
+( cd etc/fonts/conf.d ; rm -rf 45-latin.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/45-latin.conf 45-latin.conf )
+( cd etc/fonts/conf.d ; rm -rf 40-nonlatin.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/40-nonlatin.conf 40-nonlatin.conf )
 ( cd etc/fonts/conf.d ; rm -rf 50-user.conf )
 ( cd etc/fonts/conf.d ; ln -sf ../conf.avail/50-user.conf 50-user.conf )
-( cd etc/fonts/conf.d ; rm -rf 30-amt-aliases.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-amt-aliases.conf 30-amt-aliases.conf )
-( cd etc/fonts/conf.d ; rm -rf 40-generic.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/40-generic.conf 40-generic.conf )
+( cd etc/fonts/conf.d ; rm -rf 49-sansserif.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/49-sansserif.conf 49-sansserif.conf )
+( cd etc/fonts/conf.d ; rm -rf 65-nonlatin.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-nonlatin.conf 65-nonlatin.conf )
+( cd etc/fonts/conf.d ; rm -rf 80-delicious.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/80-delicious.conf 80-delicious.conf )
+( cd etc/fonts/conf.d ; rm -rf 51-local.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/51-local.conf 51-local.conf )
+( cd etc/fonts/conf.d ; rm -rf 69-unifont.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/69-unifont.conf 69-unifont.conf )
 ( cd etc/fonts/conf.d ; rm -rf 65-fonts-persian.conf )
 ( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-fonts-persian.conf 65-fonts-persian.conf )
+( cd etc/fonts/conf.d ; rm -rf 90-synthetic.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/90-synthetic.conf 90-synthetic.conf )
+( cd etc/fonts/conf.d ; rm -rf 20-unhint-small-vera.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-unhint-small-vera.conf 20-unhint-small-vera.conf )
+( cd etc/fonts/conf.d ; rm -rf 30-urw-aliases.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-urw-aliases.conf 30-urw-aliases.conf )
+( cd etc/fonts/conf.d ; rm -rf 20-fix-globaladvance.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-fix-globaladvance.conf 20-fix-globaladvance.conf )
+( cd etc/fonts/conf.d ; rm -rf 60-latin.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/60-latin.conf 60-latin.conf )
+( cd etc/fonts/conf.d ; rm -rf 30-metric-aliases.conf )
+( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-metric-aliases.conf 30-metric-aliases.conf )
+( cd usr/lib ; rm -rf libfontconfig.so.1 )
+( cd usr/lib ; ln -sf libfontconfig.so.1.3.0 libfontconfig.so.1 )
+( cd usr/lib ; rm -rf libfontconfig.so )
+( cd usr/lib ; ln -sf libfontconfig.so.1.3.0 libfontconfig.so )
